Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: chrome/browser/chromeos/drive/drive_file_system_util.h

Issue 13401003: chromeos: Replace resource ID in drive URL with path (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove unneeded include Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/chromeos/drive/drive_file_system_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/drive/drive_file_system_util.h
diff --git a/chrome/browser/chromeos/drive/drive_file_system_util.h b/chrome/browser/chromeos/drive/drive_file_system_util.h
index 0255908486f9e9245b32e316bdb6d075f5dc73f3..d7ae144ecf698ef042bba836aa7628c7728ff0aa 100644
--- a/chrome/browser/chromeos/drive/drive_file_system_util.h
+++ b/chrome/browser/chromeos/drive/drive_file_system_util.h
@@ -89,10 +89,11 @@ const std::string& GetDriveMountPointPathAsString();
// Returns the 'local' root of remote file system as "/special".
const base::FilePath& GetSpecialRemoteRootPath();
-// Returns the gdata file resource url formatted as
-// chrome://drive/<resource_id>/<file_name>.
-GURL GetFileResourceUrl(const std::string& resource_id,
- const std::string& file_name);
+// Returns the gdata file resource url formatted as "drive:<path>"
+GURL FilePathToDriveURL(const base::FilePath& path);
+
+// Converts a drive: URL back to a path that can be passed to DriveFileSystem.
+base::FilePath DriveURLToFilePath(const GURL& url);
// Given a profile and a drive_cache_path, return the file resource url.
void ModifyDriveFileResourceUrl(Profile* profile,
« no previous file with comments | « no previous file | chrome/browser/chromeos/drive/drive_file_system_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698